//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// A PositionalShape extends Shape by storing the coordinates of its
// center (which can be moved by moveCenterTo and moveCenterBy). It also
// defines an abstract methog getBounding Box. This class is abstract
// because it inherits (and doesn't override) the abstract getArea method
// and defines the abstract getBoundingBox method. 
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////


import java.awt.Point;
import java.awt.Rectangle;
import edu.cmu.cs.pattis.cs151xx.Prompt;



public abstract class PositionalShape extends Shape {

  public PositionalShape (String id, int centerX, int centerY)
  { 
    super(id);
    center = new Point(centerX,centerY);
  }
    
  //These abstract methods must be defined in a concrete subclass.
  public abstract Rectangle getBoundingBox();

  //Overide/call the method declared in Shape
  public void promptForInformation ()
  {
    super.promptForInformation();
    int x = Prompt.forInt("  Enter x coordinate for center");
    int y = Prompt.forInt("  Enter y coordinate for center");
    moveCenterTo( new Point(x,y) );
  }

  public Point getCenter ()
  {return center;}

  public double distanceTo (PositionalShape other)
  {return center.distance(other.center);}

  public void moveCenterTo (Point newCenter)
  {
    center.x = newCenter.x;
    center.y = newCenter.y;
  }

  public void moveCenterBy (int dx, int dy)
  {
    center.x += dx;
    center.y += dy;
  }

  public boolean mayOverlap (PositionalShape other)
  {return getBoundingBox().intersects(other.getBoundingBox());}
    
  public String toString ()
  {return "PositionalShape[center="+center+","+super.toString()+"]";}

  //Fields
  private Point center;
}